@@ -6,8 +6,10 @@ use base qw/Catalyst::View/;
 #use base qw/Catalyst::Base/;
 use NEXT;
 
+use Data::Dumper;
 
-our ($VERSION) = ('$Revision: 1.10 $' =~ m/([\.\d]+)/) ;
+
+our ($VERSION) = ('$Revision: 1.15 $' =~ m/([\.\d]+)/) ;
 
 
 =head1 NAME
@@ -74,15 +76,19 @@ L<Catalyst::Plugin::DefaultEnd|Catalyst::Plugin::DefaultEnd>
 =head1 CONFIGURATION
 
 The helper app automatically puts the per-application
-configuration info in C<MyApp::View::Seamstress>.
+configuration info in C<MyApp::View::Seamstress>. You configure the
+per-request information (e.g. C<< $c->stash->{template} >> and
+variables for this template) in your controller.
 
-=head2 RENDERING VIEWS
 
-=head1 The meat-skeleton paradigm
+=head2 The meat-skeleton paradigm
 
-When Catalyst::View::Seamstress is forwarded to, it can be used in 3
-ways depending on how the stash and the View config variables are set
-at that time. 
+When Catalyst::View::Seamstress is forwarded to, it will operate in one of 
+2 ways: a plain meat way or a meat-skeleton way. Plain meat is simple:
+the View takes C<< $c->stash->{template} >> and calls C<new()> and
+C<process()> on it and stores the result in 
+C<< $c->response->body >>. Meat-skeleton is designed to facilitate the
+way that web sites are typically designed. It's discussion follows:
 
 HTML pages typically have meat and a skeleton. The meat varies from page
 to page while the skeleton is fairly (though not completely) 
@@ -119,30 +125,26 @@ L<Catalyst::View::Seamstress|Catalyst::View::Seamstress> has support
 for this.
 
 
+=head3 Choosing plain-meat or meat-skeleton 
 
 There are two items which control how this plugin renders HTML.
 
 =over
 
-=item * C<< $c->stash->{template} >>
+=item * C<< $c->stash->{LOOM} >>
 
-The Seamstress view plugin MUST have a template
+The Seamstress view plugin MUST have a LOOM
 to work on or it
 will balk with an error:
 
     sub message : Global {
         my ( $self, $c ) = @_;
-        $c->stash->{template} = 'html::hello_world';
+        $c->stash->{LOOM} = 'html::hello_world';
         $c->stash->{name}     = 'Billy Bob';
         $c->stash->{date}     = 'medjool sahara';
         $c->forward('MyApp::View::Seamstress');
     }
 
-To be honest, Seamstress does not alter the HTML it unrolls, so the word
-"template" is really not accurate. But since all the other View classes
-adopted that place in the stash for the similar thing in Seamstress, we
-decided to follow suit.
-
 
 =item * C<< MyApp::View::Seamstress->config->{skeleton} >>
 
@@ -174,46 +176,37 @@ The output generated by the template
 is stored in
 C<< $c->response->body >>.
 
-
-
-
-=for comment
-
- new()
-
-The constructor for the Seamstress view 
-
-
 =cut
 
+
+# The constructor for the Seamstress view
+
 sub new {
     my $self = shift;
     my $c    = shift;
 
     $self = $self->NEXT::new(@_);
+#    unshift (@INC, $c->config->{home}) ;
+#Can't locate object method "INC" via package "Path::Class::Dir" at (eval 106) line 3.
+
+
+    #warn "self_config(NEW): " . Dumper($self->config) ;
+    #warn "c_config(NEW): " . Dumper($c->config) ;
 
-    use Data::Dumper;
-    warn "self_config(NEW): " . Dumper($self->config) ;
-    warn "c_config(NEW): " . Dumper($c->config) ;
     $self;
   }
 
 
+# process()
 
-=for comment
+# C<< eval-requires >> the module specified in C<< $c->stash->{template} >>. 
+# Gets the 
+# C<HTML::Tree> representation of the file via C<new> and then calls 
+# C<< $self->process($c, $c->stash) >> to rewrite the tree. 
 
- process()
+# NOTE WELL: most views store output in C<< $c->response->body >>. Seamstress
+# stores it in C<< $c->stash->{woven} >>.
 
-C<< eval-requires >> the module specified in C<< $c->stash->{template} >>. 
-Gets the 
-C<HTML::Tree> representation of the file via C<new> and then calls 
-C<< $self->process($c, $c->stash) >> to rewrite the tree. 
-
-NOTE WELL: most views store output in C<< $c->response->body >>. Seamstress
-stores it in C<< $c->stash->{woven} >>.
-
-
-=cut
 
 sub page2tree {
   my ($self, $c, $page_class, $process_method) = @_;
@@ -235,7 +228,7 @@ sub page2tree {
       return 0;
     }
 
-    $page_object = $page_class->new; # e.g html::hello_world->new
+    $page_object = $page_class->new($c); # e.g html::hello_world->new
 
   } else {
 
@@ -271,13 +264,13 @@ sub process {
 
 
     # 
-    # render $c->stash->{template}
+    # render $c->stash->{LOOM}
     #
 
-    my $template = $c->stash->{template};
+    my $loom = $c->stash->{LOOM};
 
-    unless ($template) {
-        $c->log->debug('No template specified for rendering') if $c->debug;
+    unless ($loom) {
+        $c->log->debug('No LOOM specified for rendering') if $c->debug;
         return 0;
     }
 
@@ -286,15 +279,15 @@ sub process {
     }
 
 
-    if (ref($template) eq 'ARRAY') {
+    if (ref($loom) eq 'ARRAY') {
 
       map {
 	$meat->{$_} = $self->page2tree($c, $_);
-      } @$template;
+      } @$loom;
 
     } else {
 
-      $meat = $body = $self->page2tree($c, $template);
+      $meat = $body = $self->page2tree($c, $loom);
 
     }
 
@@ -305,7 +298,7 @@ sub process {
 
     if ($skeleton = $self->config->{skeleton}) {
       $skeleton = $self->page2tree($c, $skeleton);
-      warn "SAH: ", $skeleton->as_HTML;
+      #warn "SAH: ", $skeleton->as_HTML;
       $self->config->{meat_pack}->(
 	$self, $c, $c->stash, $meat, $skeleton
        );
@@ -316,6 +309,11 @@ sub process {
       $body = $skeleton ;
     }
 
+    #
+    #
+    #
+    $self->config->{fixup}->($body, $c);
+
     # 
     # take the the body 
     #
@@ -329,7 +327,20 @@ sub process {
 
 =head1 Tips to View Writers
 
-=head2 get config information from MyApp and MyApp::View::Seamstress
+=head2 The order of use base is VERY significant
+
+When your helper module creates C<MyApp::V::Seamstress> it is B<very> 
+important for the C<use base> to look this way:
+
+  use base qw(Catalyst::View::Seamstress HTML::Seamstress );
+
+and not this way:
+
+  use base qw(HTML::Seamstress Catalyst::View::Seamstress );
+
+so that certain calls (probably new) get handled properly.
+
+=head2 Getting config information from MyApp and MyApp::View::*
 
 assuming C<Catalyst::View::Seamstress::new()> starts off
 like this:
@@ -338,7 +349,7 @@ like this:
     my $self = shift;
     my $c    = shift;
 
-C<< $self->config >> contains things set in C<MyApp::View::Seamstress>.
+C<< $self->config >> contains things set in C<MyApp::View::*>.
 C<< $c->config >>    contains things set in C<MyApp>
 
 assuming C<Catalyst::View::Seamstress::process()> starts off
@@ -347,7 +358,7 @@ similarly:
  sub process {
     my ( $self, $c ) = @_;
 
-C<< $self->config >> contains things set in C<MyApp::View::Seamstress>.
+C<< $self->config >> contains things set in C<MyApp::View::*>.
 C<< $c->config >>    contains things set in C<MyApp>.
 
 There is no automatic merging of the two sources of configuration: you 
